BrainPy documentation
=====================

``BrainPy`` is a lightweight framework based on the latest Just-In-Time (JIT)
compilers. The goal of ``BrainPy`` is to provide a unified simulation and
analysis framework for neuronal dynamics with the feature of high
flexibility and efficiency.

Comprehensive examples of BrainPy please see
`BrainPy-Models <https://brainpy-models.readthedocs.io/en/latest/>`_.


.. note::

    BrainPy is a project under development.
    More features are coming soon. Contributions are welcome.
    https://github.com/PKU-NIP-Lab/BrainPy


.. toctree::
   :maxdepth: 1
   :caption: API documentation

   apis/ode
   apis/sde


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
